# -*- coding: utf-8 -*-
# vim: ts=4 sts=4 expandtab ai

import datetime

import mod10

TRANSAKSJONSTYPE = {
    "10": "Giro belasta konto",
    "11": "Faste oppdrag",
    "12": "Direkte remittering",
    "13": "Bedriftsterminalgiro (BTG)",
    "14": "Skrankegiro",
    "15": "AvtaleGiro",
    "16": "TeleGiro",
    "17": "Giro - betalt kontant",
    "18": "Nettgiro - reversering m KID",
    "19": "Nettgiro - kjøp m KID",
    "20": "Nettgiro - reversering m fritekst",
    "21": "Nettgiro - kjøp m fritekst",
}

def _parse(ocr_data):
    for row in ocr_data:
        row = row.strip()
        if row[0:8] == "NY000010":
            # Startrecord for sending
            #forsendelsesnr = row[16:23]
            break
    else:
        raise OCRError('Fann ikkje startrecord for sending')

    data = []
    for row in ocr_data:
        row = row.strip()

        if row[0:6] == "NY0900":
            if row[6:8] == "20":
                # Startrecord for oppdrag
                pass
            elif row[6:8] == "88":
                # Sluttrecord for oppdrag
                pass
            else:
                raise OCRError("Forstår ikkje kode {0} ({1})!".format(row[6:8], row))
            continue

        elif row[0:4] == "NY09":
            if row[6:8] != "30":
                raise OCRError("Venta startrecord 30, fekk {0}. ({1})!".format(row[6:8], row))

            # Transaksjon
            trans = TRANSAKSJONSTYPE[row[4:6]]
            dato = row[15:21]
            dato = datetime.date(2000 + int(dato[4:6]), int(dato[2:4]), int(dato[0:2]))
            belop = int(row[32:49])/100.0
            kid = row[49:74].strip()
            if not mod10.check_number(kid.strip()):
                raise OCRError("KID-nummer validerte ikkje ({0})".format(kid))

            row2 = ocr_data.next()
            oppdr_dato = row2[41:47]
            fra_konto = row2[47:58]

            fritekst = ""
            if row[4:6] == "20" or row[4:6] == "21":
                row3 = ocr_data.next()
                fritekst = row3[15:55]

            data.append(dict(
                        transaksjon=trans,
                        dato=dato,
                        belop=belop,
                        kid=kid,
                        oppdragsdato=oppdr_dato,
                        fra_konto=fra_konto,
                        fritekst=fritekst,
                    ))
    return data

if __name__ == '__main__':
    import fileinput
    import pprint

    data = _parse(fileinput.input())
    pprint.pprint(data)



# -*- coding: utf-8 -*-
# vim: shiftwidth=4 tabstop=4 expandtab softtabstop=4 ai

# Copyright 2009-2014 Odin Hørthe Omdal

# This file is part of Medlemssys.

# Medlemssys is free software: you can redistribute it and/or modify
# it under the terms of the GNU Affero General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.

# Medlemssys is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU Affero General Public License for more details.

# You should have received a copy of the GNU Affero General Public License
# along with Medlemssys.  If not, see <http://www.gnu.org/licenses/>.
from __future__ import print_function

from django.core.management.base import BaseCommand, CommandError

from medlemssys.innhenting.management import nmu
from medlemssys.medlem.models import update_denormalized_fields
from medlemssys.statistikk.views import send_overvakingar
from medlemssys.statistikk.views import update_lokallagstat


class Command(BaseCommand):
    help = "Importerer medlemane inn i databasen"
    force_update = False

    def add_arguments(self, parser):
        super(Command, self).add_arguments(parser)
        parser.add_argument(
            '--medlem', dest='medlem_csv',
            help="fil å lesa medlemar frå")
        parser.add_argument(
            '--lokallag', dest='lokallag_csv',
            help="fil å lesa lokallag frå")
        parser.add_argument(
            '--betaling', dest='betaling_csv',
            help="fil å lesa betalingar frå")
        parser.add_argument(
            '--force-update',
            action='store_true',
            dest='force_update',
            default=False,
            help="tving gjennom oppdatering av giroar")
        parser.add_argument(
            '--importer',
            dest='importer',
            default='guess_csv',
            help="importeringssystem (guess_csv, nmu_access eller nmu_mamut)")

    def handle(self, *args, **options):
        if options['force_update']:
            self.force_update = True

        if options['importer'] == 'guess_csv':
            imp = nmu.GuessingCSVImporter()
        elif options['importer'] == 'nmu_access':
            imp = nmu.AccessImporter()
        elif options['importer'] == 'nmu_mamut':
            imp = nmu.MamutImporter()
        else:
            raise CommandError(
                "Importeren finst ikkje ({0})"
                .format(options['importer']).encode('utf8'))

        if not (options['lokallag_csv'] or options['medlem_csv'] or
                options['betaling_csv']):
            self.stdout.write(u"Ingen filer valt, ingen importering skjer.")
        if options['lokallag_csv']:
            for i in imp.import_lag(options['lokallag_csv']).values():
                self.stdout.write(u"Lag: {0}\n".format(i))

        if options['medlem_csv']:
            for i in imp.import_medlem(options['medlem_csv']):
                self.stdout.write(u"Medlem: {0}\n".format(i))

        if options['betaling_csv']:
            for i in imp.import_bet(options['betaling_csv'],
                                    force_update=self.force_update):
                self.stdout.write(u"Betaling: {0}\n".format(i))

        update_denormalized_fields()
        update_lokallagstat()
        send_overvakingar()



# -*- coding: utf-8 -*-
# Generated by Django 1.10.8 on 2019-02-27 20:01
from __future__ import unicode_literals

from django.conf import settings
from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    dependencies = [
        ('medlem', '0001_initial'),
    ]

    operations = [
        migrations.AlterField(
            model_name='giro',
            name='konto',
            field=models.CharField(choices=[('A', 'Medlemskonto (KID)'), ('M', 'Medlemskonto'), ('K', 'Kassa'), ('B', 'Brukskonto'), ('S', 'SMS'), ('V', 'Vipps')], default='M', max_length=1, verbose_name='Konto'),
        ),
        migrations.AlterField(
            model_name='medlem',
            name='betalt_av',
            field=models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.SET_NULL, related_name='betalar_for', to='medlem.Medlem'),
        ),
        migrations.AlterField(
            model_name='medlem',
            name='user',
            field=models.OneToOneField(blank=True, null=True, on_delete=django.db.models.deletion.SET_NULL, to=settings.AUTH_USER_MODEL, verbose_name='innloggingsbrukar'),
        ),
        migrations.AlterField(
            model_name='medlem',
            name='verva_av',
            field=models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.SET_NULL, related_name='har_verva', to='medlem.Medlem'),
        ),
        migrations.AlterField(
            model_name='rolle',
            name='rolletype',
            field=models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.SET_NULL, to='medlem.Rolletype'),
        ),
    ]
